@@ -20,7 +20,7 @@ use Set::Array;
 
 use Text::Xslate 'mark_raw';
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # ------------------------------------------------
 
@@ -492,6 +492,8 @@ for help on unpacking and installing distros.
 
 =head1 Installation
 
+=head2 The Module Itself
+
 Install L<Benchmark::Featureset::LocaleCountry> as you would for any C<Perl> module:
 
 Run:
@@ -516,6 +518,39 @@ or:
 	make test
 	make install
 
+=head2 The Configuration File
+
+All that remains is to tell L<Benchmark::Featureset::LocaleCountry> your values for some options.
+
+For that, see config/.htbenchmark.featureset.localecountry.conf.
+
+If you are using Build.PL, running Build (without parameters) will run scripts/copy.config.pl,
+as explained next.
+
+If you are using Makefile.PL, running make (without parameters) will also run scripts/copy.config.pl.
+
+Either way, before editing the config file, ensure you run scripts/copy.config.pl. It will copy
+the config file using L<File::HomeDir>, to a directory where the run-time code in
+L<Benchmark::Featureset::LocaleCountry> will look for it.
+
+	shell>cd Benchmark-Featureset-LocaleCountry-1.00
+	shell>perl scripts/copy.config.pl
+
+Under Debian, this directory will be $HOME/.perl/Benchmark-Featureset-LocaleCountry/. When you
+run copy.config.pl, it will report where it has copied the config file to.
+
+Check the docs for L<File::HomeDir> to see what your operating system returns for a
+call to my_dist_config().
+
+The point of this is that after the module is installed, the config file will be
+easily accessible and editable without needing permission to write to the directory
+structure in which modules are stored.
+
+That's why L<File::HomeDir> and L<Path::Class> are pre-requisites for this module.
+
+All modules which ship with their own config file are advised to use the same mechanism
+for storing such files.
+
 =head1 Constructor and Initialization
 
 C<new()> is called as C<< my($builder) = Benchmark::Featureset::LocaleCountry -> new(k1 => v1, k2 => v2, ...) >>.
